# -*- coding: utf-8 -*-

"""
Maxi's Functions
~~~~~~~~~~~~~~~~

Contains all my Functions.
Better Version

"""

from ._append_clipboard				import append_clipboard			as appendClipboard
from ._better_color_input			import better_color_input		as betterColorInput
from ._better_input					import better_input				as betterInput
from ._better_print					import better_print				as betterPrint
from ._color_input					import color_input				as colorInput
from ._key_dict						import kdict					as kdict
from ._kwargs_handler				import KWArgsHandler			as KWArgsHandler
from ._output_stdout				import output_stdout			as outputStdout
from ._repr_iterable				import repr_iter				as reprIter